@@ -176,7 +176,9 @@ static int alphatrack_write_queued (alphatrack_t *z){ /* try to send lcd data */
 
 	/*update faderposition if not touched: */
 	if ((z->faderpos != faderpos_dirty) && 
-		(!(z->buttons & ALPHATRACK_CONTACT_FADER))){
+		(!(z->buttons & ALPHATRACK_CONTACT_FADER)) 
+		&& (!(z->buttons & ALPHATRACK_CONTACT_TOUCHSTRIP_2))){
+		/*printf ("setting faderpos\n");*/
         	cmd[0] = 0x00;
         	cmd[1] = 0x02;
         	cmd[2] = (faderpos_dirty & 0xff0) >> 2;
@@ -268,7 +270,7 @@ static alphatrack_t *open_alphatrack_core(struct usb_device *dev){
 
 	val = usb_claim_interface(z->udev, 0);
 	if (val < 0){
-		printf("unable to claim alphatrack\n");
+		printf("unable to claim alphatrack (%d)\n",val);
 		free(z);
 		return NULL;
 	}
