@@ -258,7 +258,7 @@ long buffer_get_corrected_size(buffer_info_t* buf, long srate){
 */
 
 int is_inside (filechunk_t* fc, long index) {
-	if (filechunk_get_end(fc)   < index) return 0;
+	if (filechunk_get_end(fc)   <= index) return 0;
 	if (filechunk_get_start(fc) > index) return 0;
 	return 1;
 }
@@ -288,8 +288,7 @@ static float valuehelper(filechunk_t* fc, int channel, double index){
 		struct timeval tv;
 		long l = 0;
 		while (((filechunk_get_done(fc) + filechunk_get_start(fc)) 
-			< index) && (l++ < 10 /* was 1000 */)){
-/*				printf ("sleepwait\n");*/
+			< index) && (l++ < 5 /* was 1000 */)){
                                 tv.tv_sec = 0;
                                 tv.tv_usec = 10000; /* was 100*/
                                 select(0, NULL, NULL, NULL, &tv);
@@ -297,12 +296,13 @@ static float valuehelper(filechunk_t* fc, int channel, double index){
 	}
 	if (filechunk_get_length (fc) < 1 ) return 0.0;
 	if (channel == 1){
+		/*float inter4pol_float (float* buf, double index, long size);*/
         	return inter4pol_float(fc->L, index - filechunk_get_start(fc), filechunk_get_done(fc));
         } else {    
 		return inter4pol_float(fc->R, index - filechunk_get_start(fc), filechunk_get_done(fc));
 	}
 }
-
+ 
 static long wrapindex (long index, long start, long end){
 	if ((index >= start) && (index <= end)) return index;
 /*	printf ("start:%ld, end:%ld, index:%ld\n",start,end,index);*/
@@ -333,19 +333,12 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
         	}
 		if ( is_inside(buf->chunk_list[group]->readfc,index)){
 			return valuehelper(buf->chunk_list[group]->readfc,channel,index) * buf->volume_factor;
-		}else{
+		} else {
 			chunk_group_t* cg = buf->chunk_list[group];
-/*
-			printf ("not inside index:%lf.0, this=%ld-%ld, next=%ld-%ld, prev=%ld-%ld, wrap=%ld-%ld\n",
-				index,
-                                filechunk_get_start(cg->readfc),filechunk_get_end(cg->readfc),
-                                filechunk_get_start(cg->nextfc),filechunk_get_end(cg->nextfc),
-                                filechunk_get_start(cg->prevfc),filechunk_get_end(cg->prevfc),
-                                filechunk_get_start(cg->wrapfc),filechunk_get_end(cg->wrapfc));
-*/
 			long goodsize = cg->area_bandwith * 2;
 			if (goodsize < ds_buffersize) goodsize = ds_buffersize;
 		        if (!is_inside(cg->readfc,index) && is_inside(cg->nextfc,index) ) {
+				/* we are inside nextfc */
 				long wi = (long)index - cg->area_bandwith;
 				wi = wrapindex(wi, cg->area_start, 
 					cg->area_end ? cg->area_end : filechunk_get_filelength (cg->readfc));
@@ -354,14 +347,6 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
 					return valuehelper(cg->nextfc,channel,index) * buf->volume_factor;
 				}else{
 					/* not still in acceptable range */
-/*
-					printf ("next index:%.0lf, this=%ld-%ld, next=%ld-%ld, prev=%ld-%ld, wrap=%ld-%ld\n",
-                                		index,
-                                		filechunk_get_start(cg->readfc),filechunk_get_end(cg->readfc),
-                                		filechunk_get_start(cg->nextfc),filechunk_get_end(cg->nextfc),
-                                		filechunk_get_start(cg->prevfc),filechunk_get_end(cg->prevfc),
-                                		filechunk_get_start(cg->wrapfc),filechunk_get_end(cg->wrapfc));
-*/
 					long s,e;
                                		buffer_lock(buf);
 					shift_right(cg);
@@ -380,16 +365,14 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
 						long we = ws + goodsize;
 						if (we > filechunk_get_filelength(cg->readfc))
 							we = filechunk_get_filelength(cg->readfc);
-/*						printf ("set read\n");*/
 						filechunk_set(cg->wrapfc,ws, we, cg->priority, group);
 					}
-/*					printf ("set next, start:%ld, area_end:%ld \n",s,cg->area_end);*/
                                		filechunk_set(cg->nextfc,s, e, cg->priority, group);
                                		buffer_unlock(buf);
 					return valuehelper(cg->readfc,channel,index) * buf->volume_factor;
 				}
 				
-                	}else if ( !is_inside(cg->readfc,index) && is_inside(cg->prevfc,index)) {
+                	} else if (!is_inside(cg->readfc,index) && is_inside(cg->prevfc,index)) {
 				long wi = (long)index + cg->area_bandwith;
                                 wi = wrapindex(wi, cg->area_start, 
                                         cg->area_end ? cg->area_end : filechunk_get_filelength (cg->readfc));
@@ -398,7 +381,7 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
 					return valuehelper(cg->prevfc,channel,index) * buf->volume_factor;
 				}else{
                                         /* not still in acceptable range */
-/*					printf ("previous\n");*/
+					/*printf ("previous\n");*/
                     	 		long s,e;
                                		buffer_lock(buf);
 					shift_left(cg);
@@ -419,28 +402,23 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
                                		buffer_unlock(buf);
 					return valuehelper(cg->readfc,channel,index) * buf->volume_factor;
 				}
-			}else if ( !is_inside(cg->readfc,index) && is_inside_done(cg->wrapfc,index)) {
+			} else if (!is_inside(cg->readfc,index) && is_inside_done(cg->wrapfc,index)) {
 				return valuehelper(cg->wrapfc,channel,index) * buf->volume_factor;
 				/* should be more sophisticated here */
-                	}else{
-/*
-				printf ("different: index:%.0lf this=%ld-%ld, next=%ld-%ld, prev=%ld-%ld, wrap=%ld-%ld\n",
-				index,
-				filechunk_get_start(cg->readfc),filechunk_get_end(cg->readfc),
-				filechunk_get_start(cg->nextfc),filechunk_get_end(cg->nextfc),
-				filechunk_get_start(cg->prevfc),filechunk_get_end(cg->prevfc),
-				filechunk_get_start(cg->wrapfc),filechunk_get_end(cg->wrapfc));
-*/
+                	} else {
 				long s,e;
 				s = (long)index - (goodsize / 2);
 				e = (long)index + (goodsize / 2);
-				if (s < 0) s = 0;
+				if (s < 0) {s = 0;e = goodsize;}
 				if (e > filechunk_get_filelength(cg->readfc)) 
 					e = filechunk_get_filelength(cg->readfc);
 				buffer_lock(buf);
 				if (cg->priority == DS_PRIORITY_RELAXED)
 					filechunk_set(cg->readfc,s, e, cg->priority, group);
-				else	filechunk_set(cg->readfc,s, e, DS_PRIORITY_URGENT, group);
+				else {
+					filechunk_set(cg->readfc,s, e, DS_PRIORITY_URGENT, group);
+					valuehelper(cg->readfc,channel,index);
+				}
 				s += goodsize;
 				if (s < cg->area_end)
 					e = s + goodsize;
@@ -458,20 +436,38 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
 				}
 				filechunk_set(cg->prevfc, s, e, cg->priority, group);
 				buffer_unlock(buf);
+/*
+				if (group == 4){
+                                        printf ("fcs rearranged index:%.0lf, goodsize:%ld, group:%d, read=%ld-%ld, next=%ld-%ld, prev=%ld-%ld, wrap=%ld-%ld\n",
+                                                index,goodsize, group,
+                                                filechunk_get_start(cg->readfc),filechunk_get_end(cg->readfc),
+                                                filechunk_get_start(cg->nextfc),filechunk_get_end(cg->nextfc),
+                                                filechunk_get_start(cg->prevfc),filechunk_get_end(cg->prevfc),
+                                                filechunk_get_start(cg->wrapfc),filechunk_get_end(cg->wrapfc));
+                                        fflush(stdout);
+                                }
+*/
 
-				if (cg->priority == DS_PRIORITY_RELAXED)
+
+/*				if (cg->priority == DS_PRIORITY_RELAXED)*/
 					return valuehelper(cg->readfc,channel,index) * buf->volume_factor;
 
-/*				printf ("sample = zero because cpu = too slow\n");*/
+				/*printf ("sample = zero because cpu = too slow\n");*/
 				return 0.;
 			}
 		}
-	} else {
-		if (dindex >= (double)buffer_get_size(buf)) return 0;
+	} else { /* not a diskstream */
+		if (dindex >= (double)buffer_get_size(buf)) {
+			/*printf ("ouside read bounds\n");*/
+			return 0.0;
+		}
 
 		/* LATER: wrap interpolation around loopborders */
 		/* this is quite expensive: */
-		if (filechunk_get_length (buf->chunk_list[group]->readfc) < 1) return 0.0;
+		if (filechunk_get_length (buf->chunk_list[group]->readfc) < 1){
+			printf ("chunk too small\n");
+ 			return 0.0;
+		}
 		if (channel == 1){ 
 			return inter4pol_float(buf->chunk_list[group]->readfc->L,
 					dindex,(double)buffer_get_size(buf) * (double)buf->samplerate_factor) 
@@ -488,7 +484,7 @@ float buffer_readsample_interpolated(buffer_info_t* buf, int channel, double ind
 void buffer_writesample(buffer_info_t* buf, int channel, long index, int group, float sample){
 	if (!buf) return;
 	if (!buf->chunk_list) return;
-        if (!buf->group_max < group) return;
+        if (!(buf->group_max >= group)) return;
 	if (!buf->chunk_list[0]->readfc) return;
 	if (buf->type == BUFFER_TYPE_DISCSTREAM) return;  /* never write to a discstream */
 
@@ -500,7 +496,7 @@ void buffer_writesample(buffer_info_t* buf, int channel, long index, int group,
 void buffer_write_sampleblock(buffer_info_t* buf, long index, long size, int group, float* Lbuf, float* Rbuf){
 	if (!buf) return;
 	if (!buf->chunk_list) return;
-	if (!buf->group_max < group) return;
+	if (!(buf->group_max >= group)) return;
 	if (!buf->chunk_list[0]->readfc) return;
 	if (buf->type == BUFFER_TYPE_DISCSTREAM) return;  /* never write to a discstream */
 
