@@ -62,6 +62,7 @@ void filechunk_delete(filechunk_t* fc){
 }
 long filechunk_get_start (filechunk_t* fc){
         if (!fc) return -1;
+	//printf ("%p filescunkstart",fc);
         return fc->start;
 }
 
@@ -265,6 +266,7 @@ long filechunk_set (filechunk_t* fc, long start, long end, int priority, int gro
 	else */fc->done = 0;
 
 /*	printf ("resized to:%ld, with priority %d and group %d\n",fc->length,fc->priority, fc->group);*/
+	filechunk_read_chunk(fc);
 
         return fc->length;
 }
