@@ -274,9 +274,9 @@ int process (jack_nframes_t nframes, void *arg){
         jack_default_audio_sample_t *rh;
         
 	info->inside = -3;                                        
-        if (pthread_mutex_trylock (&info->mix_thread_lock)){
-		/*printf ("lock not possible \n");*/
-		/* HIER STIMMT WAS NICHT */
+	/*printf ("processing\n");*/
+        if ((i=pthread_mutex_trylock (&info->mix_thread_lock))){
+		/*printf ("lock not possible:%d, (EBUSY=%d) \n",i , EBUSY);*/
 		pthread_cond_broadcast (&info->data_ready);
         	info->inside = 2;
         	pthread_mutex_unlock (&info->mix_thread_lock);
@@ -302,7 +302,7 @@ int process (jack_nframes_t nframes, void *arg){
 	info->inside = -1; 
 	info->inrounds++;	
         info->last_nframes = nframes;
-      
+	
         if (info->submixes){ 
                 for (i = 0; i < info->nmixes;i++){
                         if (info->submixes[i]){
@@ -365,7 +365,8 @@ int process (jack_nframes_t nframes, void *arg){
                         }
                 }
         }
-       	/*pthread_cond_signal (&info->data_ready);*/
+	/*printf ("processing done\n");*/
+	/*pthread_cond_signal (&info->data_ready);*/
 	pthread_cond_broadcast (&info->data_ready);
 	info->inside = 2;
        	pthread_mutex_unlock (&info->mix_thread_lock);
@@ -395,6 +396,7 @@ static void* mix_thread(void *arg){
 	int cc = 0;
 	char *clientname = malloc(jack_client_name_size() * sizeof(char));
 	jack_status_t status;
+	int retval;
 
         jack_set_error_function ((void*)errfunc);
 
@@ -439,8 +441,10 @@ static void* mix_thread(void *arg){
         pthread_setcancelstate (PTHREAD_CANCEL_ENABLE, NULL);
         pthread_setcanceltype (PTHREAD_CANCEL_ASYNCHRONOUS, NULL);
 
-	pthread_mutex_lock (&info->mix_thread_lock);
-/*	printf ("mixer thread:%d\n",(int)getpid());*/
+	if ((retval=pthread_mutex_lock (&info->mix_thread_lock))){
+		printf ("mutex_lock failed!:%d\n",retval);
+	}
+	/*printf ("mixer thread:%d\n",(int)getpid());*/
 
 	while (1){
 /*		if (info->can_process == 2) printf ("status 2\n");*/
@@ -685,7 +689,11 @@ static void* mix_thread(void *arg){
 		/* wait until process() signals more data */
 		++info->outrounds;
 		info->outside = 318;
+		/*printf ("trylock\n");
+		pthread_mutex_lock(&info->mix_thread_lock);*/
+		/*printf ("waiting\n");*/
 		pthread_cond_wait (&info->data_ready, &info->mix_thread_lock);
+		/*printf ("waiting ended\n");*/
 		info->outside = 319;
 	}/* end while always*/
 
@@ -698,6 +706,7 @@ static void* mix_thread(void *arg){
 jack_info_t* mixer_launch (speciallist_t *looperdatalist){
 	thread_info_t *info;
 	long waited = 0;
+	int retval;
 
 	/* set up communication data */
 	info = (thread_info_t*) malloc(sizeof(thread_info_t));
@@ -731,8 +740,12 @@ jack_info_t* mixer_launch (speciallist_t *looperdatalist){
 	info->rb_size = DEFAULT_RB_SIZE;
 
 	/* launch mix thread */
-	pthread_cond_init(&info->data_ready, NULL);
-	pthread_mutex_init(&info->mix_thread_lock,NULL);
+	if ((retval=pthread_cond_init(&info->data_ready, NULL))){
+		printf ("cond_init failed:%d\n",retval);
+	}
+	if((retval=pthread_mutex_init(&info->mix_thread_lock,NULL))){
+		printf ("mutex_init failed:%d\n",retval);
+	}
 	pthread_create (&info->mix_thread_id, NULL, mix_thread, info);
 
 	while (!info->can_process && (++waited < 50000)){ 
