@@ -6,6 +6,8 @@ typedef struct _jack_info{
 	jack_client_t 	*client;	
 	long 		samplerate;
 	int 		freewheeling;
+	int		suspend_playing;
+	int		suspend_recording;
 	int		alive;
 	long		xruns; 	
 	float		load;
