@@ -737,8 +737,8 @@ void looperdata_set_grainpitchtablevalue ( looper_data_t* data, double value, do
 	}else{
 		while (!found && (i < data->ngrains)){
 			if (data->grainpitchmode == GRAINPITCH_CHORD){
-				if (*(data->grainsactive + i) == 0){
-/*				if (*(data->grainpitchtable + i) == 0.){*/
+				if (*(data->grainsactive + i) == 0.){
+/*				if (*(data->grainpitchtable + i) == 0){*/
 					*(data->grainpitchtable + i) = value;
 					*(data->grainpitchvolumes + i) = vol;
 					*(data->grainsactive + i) = 1;
@@ -867,6 +867,18 @@ void looperdata_set_playpos(looper_data_t* data, double playpos){
 			1, (long)data->playpos, 0);
 }
 
+void looperdata_set_relative_playpos(looper_data_t* data, double rplaypos){
+	if (rplaypos > 1.0) rplaypos = 1.0;
+	if (rplaypos < 0.0) rplaypos = 0.0;
+        if (data->buf){
+		rplaypos = buffer_get_size(data->buf) * rplaypos;	
+		data->playpos = rplaypos;
+        	data->playindex = rplaypos;
+                buffer_readsample_interpolated(data->buf,
+                        1, (long)data->playpos, 0);
+	}
+}
+
 void looperdata_set_recpos(looper_data_t* data, long recpos){
 	data->recpos = recpos;
 }
@@ -1247,7 +1259,9 @@ void looperdata_calc_sample_stereo(looper_data_t* data, float* L, float* R){
 		for (i = 0; i < data->ngrains; i++){
 			pos = grain_inc(data,i);
 			if (*(data->grainsactive + i)){
-				if (*(data->grainindexes + i) < *(data->grainfadelengths + i)){
+				if (*(data->grainspeeds + i) == 1){ /* dont fade in/out at regular speed */
+                                        vol = 1.;
+                                } else if (*(data->grainindexes + i) < *(data->grainfadelengths + i)){
 					vol = (float)*(data->grainindexes + i) / (float)*(data->grainfadelengths + i);
 				} else if ( (ipos = (*(data->grainsizes + i) - *(data->grainindexes + i)))
 						< *(data->grainfadelengths + i)){
