@@ -14,7 +14,7 @@ typedef struct _osc_info{
 } osc_info_t;
 
 osc_info_t*  osc_info_new (speciallist_t* looperdatalist);
-void         osc_info_destroy ();
+void         osc_info_destroy (osc_info_t* oinfo);
 
 #endif /* __OSC_H__ */
 #endif /* HAVE_OSC */
