@@ -151,7 +151,7 @@ static void* peakview_workthread(void *ptr){
 peakview_t* peakview_new(buffer_info_t* buf){
 	pthread_attr_t tattr;
 	pthread_t wt;
-	int ret;
+	/*int ret;*/
 	peakview_t *view;
 	if (!buf) return NULL;
 
@@ -165,8 +165,8 @@ peakview_t* peakview_new(buffer_info_t* buf){
 	buffer_set_area(buf, view->group,0, buffer_get_size(buf), BANDWITH);
 	view->returnlist = speciallist_new();
 
-	ret = pthread_attr_init(&tattr);
-	ret = pthread_attr_setdetachstate(&tattr,PTHREAD_CREATE_DETACHED);	
+	/*ret = */ pthread_attr_init(&tattr);
+	/*ret = */ pthread_attr_setdetachstate(&tattr,PTHREAD_CREATE_DETACHED);	
 	pthread_mutex_init (&view->peakviewmutex, NULL);
 	pthread_create (&wt, &tattr, peakview_workthread, view);
 
