@@ -15,6 +15,8 @@ serialio_data_t* serialio_new();
 int serialio_open(serialio_data_t* serialio);
 void serialio_close(serialio_data_t* serialio);
 
+int serialio_set_footled (serialio_data_t* serialio, int led);
+int serialio_toggle_footled (serialio_data_t* serialio);
 int serialio_get_foot (serialio_data_t* serialio);
 
 #endif /* __SERIALIO_H__ */
