@@ -23,12 +23,16 @@ int		speciallist_count		(speciallist_t *list);
 int 		speciallist_append		(speciallist_t *list, void *data);
 int 		speciallist_delete		(speciallist_t *list, void *data);
 void*		speciallist_get_first		(speciallist_t *list);
+void*		speciallist_get_last		(speciallist_t *list);
 void*		speciallist_get_next		(speciallist_t *list, void *data);
+void*		speciallist_get_previous	(speciallist_t *list, void *data);
 int		speciallist_count_nolock	(speciallist_t *list);
 int             speciallist_append_nolock	(speciallist_t *list, void *data);
 int             speciallist_delete_nolock      	(speciallist_t *list, void *data);
 void*		speciallist_get_first_nolock	(speciallist_t *list);
+void*		speciallist_get_last_nolock	(speciallist_t *list);
 void*           speciallist_get_next_nolock    	(speciallist_t *list, void *data);
+void* 		speciallist_get_previous_nolock (speciallist_t *list, void *data);
 
 
 
