@@ -231,16 +231,27 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
                 while ((looper = get_next_rc_looper(ll, looper))){
 /*                        if (ev->leds[ALPHATRACK_LED_SHIFT]){*/
 			if (ev->states & ALPHATRACK_BUTTON_FLIP){
-                                gtk_spin_button_set_value((GtkSpinButton*)looper->densityspin, 100.0);
-                                looper->encoderdelta_m = 0;
-                                setlcd_int(looper, "Graindensity:%03d   ", 100, 1);
+				if (looper->data){
+					looperdata_lock(looper->data);
+                               		looper->encoderdelta_m = 0;
+					looperdata_set_graindensity(looper->data, 100);
+                               		setlcd_int(looper, "Graindensity:%03d   ", 100, 1);
+					looperdata_unlock(looper->data);
+					looper->dirty = 1;
+				}
                         } else if (looper->encoderdelta_m){
-				gtk_spin_button_set_value((GtkSpinButton*)looper->densityspin,
-                                        gtk_spin_button_get_value ((GtkSpinButton*)looper->densityspin) +
-                                        looper->encoderdelta_m);
-                                looper->encoderdelta_m = 0;
-                                setlcd_int(looper, "Grainsdensty:%03d   ",
-					gtk_spin_button_get_value ((GtkSpinButton*)looper->densityspin),1);
+				if (looper->data){
+                                        looperdata_lock(looper->data);
+                                        looperdata_set_graindensity(looper->data,
+                                                looperdata_get_graindensity(looper->data) +
+                                                looper->encoderdelta_m);
+                                        	looper->encoderdelta_m = 0;
+                                        setlcd_int(looper, "Graindensity:%03d   ",
+						looperdata_get_graindensity(looper->data), 1); 
+					/*printf ("dens:%d\n",looperdata_get_graindensity(looper->data));*/
+					looperdata_unlock(looper->data);
+                                        looper->dirty = 1;
+                               }
                         }
                 }
         }
@@ -293,17 +304,26 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
 				}
 			} else {
 				if (ev->states & ALPHATRACK_BUTTON_FLIP){
-				gtk_spin_button_set_value((GtkSpinButton*)looper->speedspin, 1.0);
-					looper->encoderdelta_r = 0;
-					setlcd_float(looper, "Speed:  %03.3f   ", 1.0, 1);
+					if (looper->data){
+						looperdata_lock(looper->data);
+                                        	looperdata_set_speed(looper->data,1.0);
+                                        	looperdata_unlock(looper->data);
+						looper->dirty = 1;
+						setlcd_float(looper, "Speed:  %03.3f   ", 1.0, 1);
+					}
 				} else if (looper->encoderdelta_r){	
-                                	gtk_spin_button_set_value((GtkSpinButton*)looper->speedspin,
-						(float)gtk_spin_button_get_value ((GtkSpinButton*)looper->speedspin) *
-                                        	powf(1.011, (float)looper->encoderdelta_r));
-                                	looper->encoderdelta_r = 0;
-                                	setlcd_float(looper, "Speed:  %03.3f   ",
-						(float)gtk_spin_button_get_value ((GtkSpinButton*)looper->speedspin) *
-                                        	powf(1.011, (float)looper->encoderdelta_r), 1);
+					if (looper->data){
+						looperdata_lock(looper->data);
+						looperdata_set_speed(looper->data, 
+							looperdata_get_speed(looper->data) * 
+                                                	powf(1.011, (float)looper->encoderdelta_r));
+						looper->encoderdelta_r = 0;
+						looperdata_unlock(looper->data);
+						looper->dirty = 1;
+						setlcd_float(looper, "Speed:  %03.3f   ",
+                                                	(float)gtk_spin_button_get_value ((GtkSpinButton*)looper->speedspin) *
+                                                	powf(1.011, (float)looper->encoderdelta_r), 1);
+					}
                         	}
 			}
                 }
@@ -315,6 +335,7 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
                	while ((looper = get_next_rc_looper(ll, looper))){
 			if (!ev->leds[ALPHATRACK_LED_SHIFT]){
 				/* semitones pitch / speed change: */
+				printf ("touchstrip\n");
 				double f = (float)((ev->touchpos / 64) - 2);
 				if (f >= 0.) f += 1.;
 				f = pow(2.,f / 12.);
@@ -336,12 +357,14 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
 			}
 		}	
 	}
+#if 0 /* don't know what touchstrip2 is good for - seems to be the volume fader on touch*/
 	if ((ev->mask & ALPHATRACK_CONTACT_TOUCHSTRIP_2) && 
 		(ev->states & ALPHATRACK_CONTACT_TOUCHSTRIP_2)){
                	looper = NULL;
                	while ((looper = get_next_rc_looper(ll, looper))){
 			if (!ev->leds[ALPHATRACK_LED_SHIFT]){
                 		/* full tones pitch / speed change */
+				printf ("touchstrip2\n");
                        		double f = (float)((ev->touchpos / 64) - 2);
                        		if (f >= 0.) f += 1.;
                        		f = pow(2.,f / 6.);
@@ -363,6 +386,7 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
                         }
                	}
        	} 
+#endif
 	if ((ev->mask & ALPHATRACK_POS_TOUCHSTRIP) && ev->leds[ALPHATRACK_LED_SHIFT]){
 		/* change loop */
 		looper = NULL; 
@@ -377,11 +401,12 @@ void alphatrack_event_callback(alphatrack_event_t *ev, void *ptr){
 					looperdata_set_loopend(looper->data,
 						(long)(f + looper->touchstripposrange));
 					looperdata_set_loopstart(looper->data,(long)f);
-					if (looper->data->linkrec2play)		
+					if (looper->data->linkrec2play){
 						looperdata_set_recstart(looper->data,
 							looperdata_get_loopstart(looper->data));
 						looperdata_set_recend(looper->data,
                                                         looperdata_get_loopend(looper->data));
+					}
 					looperdata_unlock(looper->data);
 					looper->dirty = 1;
 				}
