@@ -34,7 +34,7 @@ static void offset_callback(GtkWidget* offsetspin, gpointer data){
 
 void griddialog_new(GtkWidget* parent, GtkLoopview *loopview){
 	GtkAdjustment 	*adj;
-	GtkTooltips     *tooltips;
+	/*GtkTooltips     *tooltips;*/
         GtkWidget       *dialog;
         GtkWidget       *bpmlabel;
         GtkWidget       *bpblabel;
@@ -49,9 +49,9 @@ void griddialog_new(GtkWidget* parent, GtkLoopview *loopview){
         GtkWidget       *bpmspin;       /* spinbutton */
         GtkWidget       *bpbspin;      	/* spinbutton */
 	GtkWidget	*offsetspin;	/* spinbutton */
-	gint result;
+	/*gint result;*/
 
-	tooltips = gtk_tooltips_new ();
+	/*tooltips = gtk_tooltips_new ();*/
 
 	
 	bpmlabel = gtk_label_new ("beats per minute");
@@ -119,7 +119,7 @@ void griddialog_new(GtkWidget* parent, GtkLoopview *loopview){
 	gtk_container_add (GTK_CONTAINER (GTK_DIALOG(dialog)->vbox),mainbox);
 	gtk_widget_show_all (dialog);
 
-	result = gtk_dialog_run (GTK_DIALOG (dialog));
+	/*result = */ gtk_dialog_run (GTK_DIALOG (dialog));
         gtk_widget_destroy (dialog);
 }
 
