@@ -46,6 +46,9 @@ struct _GtkLoopview
 	/* peakview */
 	peakview_t *peakview;
 
+	/* graphics active ? */
+	gboolean suspended;
+
 	/* pointer position */
 	gint pointerX;
 	gint pointerY;
@@ -137,6 +140,7 @@ GtkType        	gtk_loopview_get_type            	(void);
 looper_data_t* 	gtk_loopview_get_looperdata     	(GtkLoopview *loopview);
 void           	gtk_loopview_set_update_policy   	(GtkLoopview *loopview, GtkUpdateType  policy);
 void           	gtk_loopview_set_looperdata     	(GtkLoopview *loopview, looper_data_t *looperdata);
+void 		gtk_loopview_suspend_gui 		(GtkLoopview *loopview, int suspend);
 void	       	gtk_loopview_set_play_pos		(GtkLoopview *loopview, gdouble playpos);
 void           	gtk_loopview_set_rec_pos         	(GtkLoopview *loopview, gdouble recpos);
 /*void 	       	gtk_loopview_calc_peaks	        	(GtkLoopview *loopview,guint32 startx, guint32 endx);*/
